==> moxn_models-0.0.6.8.tar.gz: moxn_models-0.0.6.8/moxn_models/blocks/image.py <==
from enum import Enum
from moxn_models.blocks.base import BaseContent
from typing import Literal, Annotated
from pathlib import Path
from pydantic import Field


class MediaDataImageFormat(str, Enum):
    BASE64 = "base64"
    BYTES = "bytes"
    GOOGLE_FILE = "google_file"
    GOOGLE_FILE_REFERENCE = "google_file_reference"
    LOCAL_FILE = "local_file"
    URL = "url"


class _ImageBase(BaseContent):
    """Base class for image content with common properties."""

    media_type: Literal["image/jpeg", "image/png", "image/gif", "image/webp"]


class MediaImageFromBase64Model(_ImageBase):
    """
    Image encoded in base64 format.
    """

    type: Literal[MediaDataImageFormat.BASE64] = MediaDataImageFormat.BASE64
    base64: str


class MediaImageFromBytesModel(_ImageBase):
    """
    Image provided as raw bytes.
    """

    type: Literal[MediaDataImageFormat.BYTES] = MediaDataImageFormat.BYTES
    bytes: bytes


class MediaImageFromURLModel(_ImageBase):
    """
    Image referenced by a URL.
    Note: For Google Vertex AI, public HTTP URLs are NOT supported for images.
    """

    type: Literal[MediaDataImageFormat.URL] = MediaDataImageFormat.URL
    url: str


class MediaImageFromLocalFileModel(_ImageBase):
    """
    Image loaded from a local file path.
    """

    type: Literal[MediaDataImageFormat.LOCAL_FILE] = MediaDataImageFormat.LOCAL_FILE
    filepath: Path


class MediaImageFromGoogleFileModel(_ImageBase):
    """
    Image provided as a Google File object.
    Only supported by Google Gemini.
    """

    type: Literal[MediaDataImageFormat.GOOGLE_FILE] = MediaDataImageFormat.GOOGLE_FILE
    file: object  # We'll use object here since we can't directly import types.File


class MediaImageFromGoogleFileReferenceModel(_ImageBase):
    """
    Image referenced by a Google File URI.
    For Gemini Developer API: can be any URI
    For Vertex AI: must be a GCS URI (gs://)
    """

    type: Literal[MediaDataImageFormat.GOOGLE_FILE_REFERENCE] = (
        MediaDataImageFormat.GOOGLE_FILE_REFERENCE
    )
    uri: str  # gs://


# Type for discriminated union (without implementation)
_ImageContentFromSourceTypesModel = (
    MediaImageFromBase64Model
    | MediaImageFromBytesModel
    | MediaImageFromURLModel
    | MediaImageFromLocalFileModel
    | MediaImageFromGoogleFileModel
    | MediaImageFromGoogleFileReferenceModel
)

ImageContentFromSourceModel = Annotated[
    _ImageContentFromSourceTypesModel,
    Field(discriminator="type"),
]

==> moxn_models-0.0.6.11.tar.gz: moxn_models-0.0.6.11/moxn_models/blocks/image.py <==
from pydantic import Field
from enum import Enum
from moxn_models.blocks.base import BaseContent
from typing import Literal
from pathlib import Path
from typing import Annotated

class MediaDataImageFormat(str, Enum):
    BASE64 = "base64"
    BYTES = "bytes"
    GOOGLE_FILE = "google_file"
    GOOGLE_FILE_REFERENCE = "google_file_reference"
    LOCAL_FILE = "local_file"
    URL = "url"


class _ImageBase(BaseContent):
    """Base class for image content with common properties."""

    media_type: Literal["image/jpeg", "image/png", "image/gif", "image/webp"]


class MediaImageFromBase64Model(_ImageBase):
    """
    Image encoded in base64 format.
    """

    type: Literal[MediaDataImageFormat.BASE64] = MediaDataImageFormat.BASE64
    base64: str


class MediaImageFromBytesModel(_ImageBase):
    """
    Image provided as raw bytes.
    """

    type: Literal[MediaDataImageFormat.BYTES] = MediaDataImageFormat.BYTES
    bytes: bytes


class MediaImageFromURLModel(_ImageBase):
    """
    Image referenced by a URL.
    Note: For Google Vertex AI, public HTTP URLs are NOT supported for images.
    """

    type: Literal[MediaDataImageFormat.URL] = MediaDataImageFormat.URL
    url: str


class MediaImageFromLocalFileModel(_ImageBase):
    """
    Image loaded from a local file path.
    """

    type: Literal[MediaDataImageFormat.LOCAL_FILE] = MediaDataImageFormat.LOCAL_FILE
    filepath: Path


class MediaImageFromGoogleFileModel(_ImageBase):
    """
    Image provided as a Google File object.
    Only supported by Google Gemini.
    """

    type: Literal[MediaDataImageFormat.GOOGLE_FILE] = MediaDataImageFormat.GOOGLE_FILE
    file: object  # We'll use object here since we can't directly import types.File


class MediaImageFromGoogleFileReferenceModel(_ImageBase):
    """
    Image referenced by a Google File URI.
    For Gemini Developer API: can be any URI
    For Vertex AI: must be a GCS URI (gs://)
    """

    type: Literal[MediaDataImageFormat.GOOGLE_FILE_REFERENCE] = (
        MediaDataImageFormat.GOOGLE_FILE_REFERENCE
    )
    uri: str  # gs://

_ImageContentFromSourceTypes = (
    MediaImageFromBase64Model
    | MediaImageFromBytesModel
    | MediaImageFromURLModel
    | MediaImageFromLocalFileModel
    | MediaImageFromGoogleFileModel
    | MediaImageFromGoogleFileReferenceModel
)
ImageContentFromSourceModel = Annotated[
    _ImageContentFromSourceTypes,
    Field(discriminator="type"),
]
